@@ -1,32 +1,29 @@
-# -*- coding: utf-8 -*-
 from copy import deepcopy
 
-from django.contrib import admin
-from django.contrib.admin.options import BaseModelAdmin, flatten_fieldsets, InlineModelAdmin
 from django import forms
+from django.contrib import admin
+from django.contrib.admin.options import BaseModelAdmin, InlineModelAdmin, flatten_fieldsets
+from django.contrib.contenttypes.admin import GenericStackedInline, GenericTabularInline
 
 from modeltranslation import settings as mt_settings
 from modeltranslation.translator import translator
 from modeltranslation.utils import (
-    get_translation_fields,
     build_css_class,
     build_localized_fieldname,
     get_language,
     get_language_bidi,
+    get_translation_fields,
     unique,
 )
 from modeltranslation.widgets import ClearableWidgetWrapper
 
-from django.contrib.contenttypes.admin import GenericTabularInline
-from django.contrib.contenttypes.admin import GenericStackedInline
-
 
 class TranslationBaseModelAdmin(BaseModelAdmin):
     _orig_was_required = {}
     both_empty_values_fields = ()
 
     def __init__(self, *args, **kwargs):
-        super(TranslationBaseModelAdmin, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.trans_opts = translator.get_options_for_model(self.model)
         self._patch_prepopulated_fields()
 
@@ -47,9 +44,7 @@ class TranslationBaseModelAdmin(BaseModelAdmin):
         return None
 
     def formfield_for_dbfield(self, db_field, request, **kwargs):
-        field = super(TranslationBaseModelAdmin, self).formfield_for_dbfield(
-            db_field, request, **kwargs
-        )
+        field = super().formfield_for_dbfield(db_field, request, **kwargs)
         self.patch_translation_field(db_field, field, request, **kwargs)
         return field
 
@@ -271,7 +266,7 @@ class TranslationAdmin(TranslationBaseModelAdmin, admin.ModelAdmin):
     group_fieldsets = False
 
     def __init__(self, *args, **kwargs):
-        super(TranslationAdmin, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._patch_list_editable()
 
     def _patch_list_editable(self):
@@ -297,7 +292,7 @@ class TranslationAdmin(TranslationBaseModelAdmin, admin.ModelAdmin):
             flattened_fieldsets = flatten_fieldsets(fieldsets)
 
             # Create a fieldset to group each translated field's localized fields
-            fields = sorted((f for f in self.opts.get_fields() if f.concrete))
+            fields = sorted(f for f in self.opts.get_fields() if f.concrete)
             untranslated_fields = [
                 f.name
                 for f in fields
@@ -352,7 +347,7 @@ class TranslationAdmin(TranslationBaseModelAdmin, admin.ModelAdmin):
 
     def get_form(self, request, obj=None, **kwargs):
         kwargs = self._get_form_or_formset(request, obj, **kwargs)
-        return super(TranslationAdmin, self).get_form(request, obj, **kwargs)
+        return super().get_form(request, obj, **kwargs)
 
     def get_fieldsets(self, request, obj=None):
         return self._get_fieldsets_pre_form_or_formset(request, obj) or self._group_fieldsets(
@@ -365,7 +360,7 @@ class TranslationAdmin(TranslationBaseModelAdmin, admin.ModelAdmin):
 class TranslationInlineModelAdmin(TranslationBaseModelAdmin, InlineModelAdmin):
     def get_formset(self, request, obj=None, **kwargs):
         kwargs = self._get_form_or_formset(request, obj, **kwargs)
-        return super(TranslationInlineModelAdmin, self).get_formset(request, obj, **kwargs)
+        return super().get_formset(request, obj, **kwargs)
 
     def get_fieldsets(self, request, obj=None):
         # FIXME: If fieldsets are declared on an inline some kind of ghost
