@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from django import forms
 from django.core import validators
 
@@ -7,7 +6,7 @@ from modeltranslation.fields import TranslationField
 
 class TranslationModelForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
-        super(TranslationModelForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         for f in self._meta.model._meta.fields:
             if f.name in self.fields and isinstance(f, TranslationField):
                 del self.fields[f.name]
@@ -21,7 +20,7 @@ class NullCharField(forms.CharField):
     def to_python(self, value):
         if value in validators.EMPTY_VALUES:
             return None
-        return super(NullCharField, self).to_python(value)
+        return super().to_python(value)
 
 
 class NullableField(forms.Field):
@@ -33,7 +32,7 @@ class NullableField(forms.Field):
     def to_python(self, value):
         if value is None:
             return value
-        return super(NullableField, self).to_python(value)
+        return super().to_python(value)
 
     # Django 1.6
     def _has_changed(self, initial, data):
@@ -42,7 +41,7 @@ class NullableField(forms.Field):
     def has_changed(self, initial, data):
         if (initial is None and data is not None) or (initial is not None and data is None):
             return True
-        obj = super(NullableField, self)
+        obj = super()
         if hasattr(obj, 'has_changed'):
             return obj.has_changed(initial, data)
         else:  # Django < 1.9 compat
